ResolveOptions

Struct ResolveOptions 

pub struct ResolveOptions {
    pub branch: Option<String>,
    pub commit: Option<String>,
    pub path: Option<String>,
    pub recursive: Option<bool>,
    pub max_depth: Option<usize>,
}
Options for resolving a NAP URI. All are optional — omitting all causes the resolver to use its ResolveConfig::default_branch (if configured) or fail with NapError::NoDefaultBranch.

Fields

branch: Option<String>

Resolve at a specific branch. e.g., "canon". Takes precedence over ResolveConfig::default_branch.

commit: Option<String>

Resolve at a specific commit hash (BLAKE3). e.g., "af1349b9f5f9a1a6a0404deb36d020949b834f2a42e37e5f8d2e4ba2765f1a2f". Takes precedence over branch and ResolveConfig::default_branch.

path: Option<String>

Subtree query path (overrides URI fragment). e.g., "appearances.audienceVotes".

recursive: Option<bool>

Recursively resolve nested URIs. When true, the resolver will follow all nap:// URIs found in the resolved manifest and resolve them as well.

max_depth: Option<usize>

Maximum recursion depth for recursive resolution. Defaults to 10 to prevent infinite loops. Set to None for unlimited depth (not recommended).