Module error_ids

Module error_ids 

Error IDs for diagnostic tracking.

These IDs should be used in all error contexts to allow Sentry to aggregate and track specific failure modes in production.

Constants

ERR_LORE_CERT_FAILED
Lore certificate generation failed
ERR_LORE_CONFIG_FAILED
Lore configuration generation failed
ERR_LORE_DOWNLOAD_FAILED
Lore download failed
ERR_LORE_INCOMPATIBLE
Lore compatibility check failed
ERR_LORE_INSTALL_FAILED
Lore install script failed
ERR_LORE_STARTUP_FAILED
Lore process failed to start/become healthy