Persistent logging for NAP SDK and Lore server
Provides structured logging to persistent files for diagnostics and support.
Structs
- LogFile
Info - Log file information
Functions
- clear_
logs - Clear log files
- init_
persistent_ logging - Initialize persistent logging for NAP SDK
- init_
rolling_ logging - Initialize rolling log files with rotation
- log_
file_ size - Get log file size in bytes
- log_
files_ info - Get information about all log files
- lore_
log_ path - Get the path to the Lore server log file
- nap_
log_ path - Get the path to the NAP log file
- read_
recent_ logs - Read recent log entries from a file
- tail_
log - Tail a log file (return last N lines)
- total_
log_ size - Get total size of all log files