get_engine

Function get_engine 

pub fn get_engine() -> StorageResult<&'static StorageEngine>
Return a reference to the globally-initialised StorageEngine.

The engine is lazily initialised on first access using StorageEngine::from_env. Subsequent calls return the same instance.

Errors

Returns StorageError::Init if environment variables are invalid or the backend cannot be configured.