pub fn check_required_paths(
schema: &SdlDocument,
value: &Value,
) -> Vec<ValidationError>Expand description
Check that all required paths exist in a value.
pub fn check_required_paths(
schema: &SdlDocument,
value: &Value,
) -> Vec<ValidationError>Check that all required paths exist in a value.