Module logging

Module logging 

Persistent logging for NAP SDK and Lore server

Provides structured logging to persistent files for diagnostics and support.

Structs

LogFileInfo
Log file information

Functions

clear_logs
Clear log files
init_persistent_logging
Initialize persistent logging for NAP SDK
init_rolling_logging
Initialize rolling log files with rotation
log_file_size
Get log file size in bytes
log_files_info
Get information about all log files
lore_log_path
Get the path to the Lore server log file
nap_log_path
Get the path to the NAP log file
read_recent_logs
Read recent log entries from a file
tail_log
Tail a log file (return last N lines)
total_log_size
Get total size of all log files